"predict"(object,newdata, quick = FALSE, return.subclass.prediction = TRUE, ...)locpvs, as that created by the function locpvspvs-model are used. predict calls.return.subclass.prediction=TRUE. A matrix containing posterior probabalities for the subclasses. pvs-model with the subclasses as classes. Then the posterior probabalities are summed over all subclasses for each class. The class with the highest value becomes the prediction.If quick=FALSE the posterior probabilites for each case are computed using the pairwise coupling algorithm presented by Hastie, Tibshirani (1998). If quick=FALSE a much quicker solution is used, which leads to less accurate posterior probabalities. In almost all cases it doesn't has a negative effect on the classification result.
locpvs for learning locpvs-models and examples for applying this predict method, pvs for pairwise variable selection without modeling subclasses, predict.pvs for predicting pvs-models