"predict"(object, newdata, quick = FALSE, detail = FALSE, ...)pvs, as that created by the function pvs pvs-model are used. predict calls.details=TRUE. A list containing matrices of posterior probabalities computated by the classification method for each case and classpair. quick=FALSE the posterior probabilites for each case are computed using the pairwise coupling algorithm presented by Hastie, Tibshirani (1998).
If quick=FALSE a much quicker solution is used, which leads to less accurate posterior probabalities.
In almost all cases it doesn't has a negative effect on the classification result.
pvs.